summaryrefslogtreecommitdiff
path: root/test/application_tests/application_test_starter.sh
diff options
context:
space:
mode:
Diffstat (limited to 'test/application_tests/application_test_starter.sh')
-rwxr-xr-xtest/application_tests/application_test_starter.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/application_tests/application_test_starter.sh b/test/application_tests/application_test_starter.sh
index 3efc1b4..bb17515 100755
--- a/test/application_tests/application_test_starter.sh
+++ b/test/application_tests/application_test_starter.sh
@@ -25,12 +25,12 @@ fi
cat <<End-of-message
*******************************************************************************
*******************************************************************************
** Now running same tests with vsomeipd
*******************************************************************************
*******************************************************************************
End-of-message
export VSOMEIP_CONFIGURATION=application_test_no_dispatch_threads_daemon.json
-../daemon/./vsomeipd &
+../examples/routingmanagerd/./routingmanagerd &
DAEMON_PID=$!
./application_test
if [ $? -ne 0 ]
@@ -42,7 +42,7 @@ kill $DAEMON_PID
wait $DAEMON_PID
export VSOMEIP_CONFIGURATION=application_test_daemon.json
-../daemon/./vsomeipd &
+../examples/routingmanagerd/./routingmanagerd &
DAEMON_PID=$!
./application_test
if [ $? -ne 0 ]
@@ -25,12 +25,12 @@ fi
*******************************************************************************
*******************************************************************************
-** Now running same tests with vsomeipd
+** Now running same tests with routingmanagerd
*******************************************************************************
*******************************************************************************